pub struct PackageName(/* private fields */);Expand description
Validated package name metadata.
Implementations
Sourceimpl PackageName
impl PackageName
Sourcepub fn new(input: &str) -> Result<PackageName, PackageJsonTextError>
pub fn new(input: &str) -> Result<PackageName, PackageJsonTextError>
Creates lightly validated package name metadata.
Errors
Returns PackageJsonTextError when input is empty, contains whitespace, or has an invalid scoped shape.
Examples found in repository?
examples/basic_usage.rs (line 6)
3fn main() -> Result<(), Box<dyn std::error::Error>> {
4 let target: EcmaScriptTarget = "es2024".parse()?;
5 let identifier = JsIdentifier::new("createApp")?;
6 let package = PackageName::new("@rustuse/example")?;
7 let component = ReactComponentName::new("AppShell")?;
8
9 assert_eq!(target.to_string(), "ES2024");
10 assert_eq!(identifier.as_str(), "createApp");
11 assert!(package.is_scoped());
12 assert_eq!(component.as_str(), "AppShell");
13 Ok(())
14}Sourcepub fn is_scoped(&self) -> bool
pub fn is_scoped(&self) -> bool
Returns whether this package name is scoped.
Examples found in repository?
examples/basic_usage.rs (line 11)
3fn main() -> Result<(), Box<dyn std::error::Error>> {
4 let target: EcmaScriptTarget = "es2024".parse()?;
5 let identifier = JsIdentifier::new("createApp")?;
6 let package = PackageName::new("@rustuse/example")?;
7 let component = ReactComponentName::new("AppShell")?;
8
9 assert_eq!(target.to_string(), "ES2024");
10 assert_eq!(identifier.as_str(), "createApp");
11 assert!(package.is_scoped());
12 assert_eq!(component.as_str(), "AppShell");
13 Ok(())
14}Trait Implementations
Sourceimpl Clone for PackageName
impl Clone for PackageName
Sourcefn clone(&self) -> PackageName
fn clone(&self) -> PackageName
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for PackageName
impl Debug for PackageName
Sourceimpl<'de> Deserialize<'de> for PackageName
impl<'de> Deserialize<'de> for PackageName
Sourcefn deserialize<__D>(
__deserializer: __D,
) -> Result<PackageName, <__D as Deserializer<'de>>::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(
__deserializer: __D,
) -> Result<PackageName, <__D as Deserializer<'de>>::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl Display for PackageName
impl Display for PackageName
Sourceimpl FromStr for PackageName
impl FromStr for PackageName
Sourcetype Err = PackageJsonTextError
type Err = PackageJsonTextError
The associated error which can be returned from parsing.
Sourcefn from_str(input: &str) -> Result<PackageName, <PackageName as FromStr>::Err>
fn from_str(input: &str) -> Result<PackageName, <PackageName as FromStr>::Err>
Parses a string
s to return a value of this type. Read moreSourceimpl Hash for PackageName
impl Hash for PackageName
Sourceimpl Ord for PackageName
impl Ord for PackageName
Sourcefn cmp(&self, other: &PackageName) -> Ordering
fn cmp(&self, other: &PackageName) -> Ordering
1.21.0 (const: unstable) · Sourcefn max(self, other: Self) -> Selfwhere
Self: Sized,
fn max(self, other: Self) -> Selfwhere
Self: Sized,
Compares and returns the maximum of two values. Read more
Sourceimpl PartialEq for PackageName
impl PartialEq for PackageName
Sourcefn eq(&self, other: &PackageName) -> bool
fn eq(&self, other: &PackageName) -> bool
Tests for
self and other values to be equal, and is used by ==.Sourceimpl PartialOrd for PackageName
impl PartialOrd for PackageName
Sourceimpl Serialize for PackageName
impl Serialize for PackageName
Sourcefn serialize<__S>(
&self,
__serializer: __S,
) -> Result<<__S as Serializer>::Ok, <__S as Serializer>::Error>where
__S: Serializer,
fn serialize<__S>(
&self,
__serializer: __S,
) -> Result<<__S as Serializer>::Ok, <__S as Serializer>::Error>where
__S: Serializer,
Serialize this value into the given Serde serializer. Read more
Sourceimpl TryFrom<&str> for PackageName
impl TryFrom<&str> for PackageName
Sourcetype Error = PackageJsonTextError
type Error = PackageJsonTextError
The type returned in the event of a conversion error.
Sourcefn try_from(
value: &str,
) -> Result<PackageName, <PackageName as TryFrom<&str>>::Error>
fn try_from( value: &str, ) -> Result<PackageName, <PackageName as TryFrom<&str>>::Error>
Performs the conversion.
impl Eq for PackageName
impl StructuralPartialEq for PackageName