pub struct JsIdentifier(/* private fields */);Expand description
Validated ASCII-safe JavaScript identifier.
Implementations
Sourceimpl JsIdentifier
impl JsIdentifier
Sourcepub fn new(input: &str) -> Result<JsIdentifier, JsIdentifierError>
pub fn new(input: &str) -> Result<JsIdentifier, JsIdentifierError>
Creates an ASCII-safe JavaScript identifier.
Errors
Returns JsIdentifierError when input is empty or not ASCII identifier-shaped.
Examples found in repository?
examples/basic_usage.rs (line 5)
3fn main() -> Result<(), Box<dyn std::error::Error>> {
4 let target: EcmaScriptTarget = "es2024".parse()?;
5 let identifier = JsIdentifier::new("createApp")?;
6 let package = PackageName::new("@rustuse/example")?;
7 let component = ReactComponentName::new("AppShell")?;
8
9 assert_eq!(target.to_string(), "ES2024");
10 assert_eq!(identifier.as_str(), "createApp");
11 assert!(package.is_scoped());
12 assert_eq!(component.as_str(), "AppShell");
13 Ok(())
14}Sourcepub fn as_str(&self) -> &str
pub fn as_str(&self) -> &str
Returns the identifier as a string slice.
Examples found in repository?
examples/basic_usage.rs (line 10)
3fn main() -> Result<(), Box<dyn std::error::Error>> {
4 let target: EcmaScriptTarget = "es2024".parse()?;
5 let identifier = JsIdentifier::new("createApp")?;
6 let package = PackageName::new("@rustuse/example")?;
7 let component = ReactComponentName::new("AppShell")?;
8
9 assert_eq!(target.to_string(), "ES2024");
10 assert_eq!(identifier.as_str(), "createApp");
11 assert!(package.is_scoped());
12 assert_eq!(component.as_str(), "AppShell");
13 Ok(())
14}Trait Implementations
Sourceimpl Clone for JsIdentifier
impl Clone for JsIdentifier
Sourcefn clone(&self) -> JsIdentifier
fn clone(&self) -> JsIdentifier
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for JsIdentifier
impl Debug for JsIdentifier
Sourceimpl Display for JsIdentifier
impl Display for JsIdentifier
Sourceimpl FromStr for JsIdentifier
impl FromStr for JsIdentifier
Sourcetype Err = JsIdentifierError
type Err = JsIdentifierError
The associated error which can be returned from parsing.
Sourcefn from_str(input: &str) -> Result<JsIdentifier, <JsIdentifier as FromStr>::Err>
fn from_str(input: &str) -> Result<JsIdentifier, <JsIdentifier as FromStr>::Err>
Parses a string
s to return a value of this type. Read moreSourceimpl Hash for JsIdentifier
impl Hash for JsIdentifier
Sourceimpl Ord for JsIdentifier
impl Ord for JsIdentifier
Sourcefn cmp(&self, other: &JsIdentifier) -> Ordering
fn cmp(&self, other: &JsIdentifier) -> Ordering
1.21.0 (const: unstable) · Sourcefn max(self, other: Self) -> Selfwhere
Self: Sized,
fn max(self, other: Self) -> Selfwhere
Self: Sized,
Compares and returns the maximum of two values. Read more
Sourceimpl PartialEq for JsIdentifier
impl PartialEq for JsIdentifier
Sourcefn eq(&self, other: &JsIdentifier) -> bool
fn eq(&self, other: &JsIdentifier) -> bool
Tests for
self and other values to be equal, and is used by ==.Sourceimpl PartialOrd for JsIdentifier
impl PartialOrd for JsIdentifier
Sourceimpl TryFrom<&str> for JsIdentifier
impl TryFrom<&str> for JsIdentifier
Sourcetype Error = JsIdentifierError
type Error = JsIdentifierError
The type returned in the event of a conversion error.
Sourcefn try_from(
value: &str,
) -> Result<JsIdentifier, <JsIdentifier as TryFrom<&str>>::Error>
fn try_from( value: &str, ) -> Result<JsIdentifier, <JsIdentifier as TryFrom<&str>>::Error>
Performs the conversion.
impl Eq for JsIdentifier
impl StructuralPartialEq for JsIdentifier