pub struct VueDirectiveName(/* private fields */);Expand description
Validated Vue directive name metadata without the leading v-.
Implementations
Sourceimpl VueDirectiveName
impl VueDirectiveName
Sourcepub fn new(input: &str) -> Result<VueDirectiveName, VueNameError>
pub fn new(input: &str) -> Result<VueDirectiveName, VueNameError>
Creates a directive name, accepting an optional leading v-.
Errors
Returns VueNameError when input is empty or contains whitespace.